@@ -12,7 +12,7 @@ use Exporter::Tidy all => [
 
 # ABSTRACT: Serialisation similar to Bencode + undef/UTF8
 
-our $VERSION = '2.000_6';
+our $VERSION = '2.000_7';
 our $max_depth;
 our @CARP_NOT = (__PACKAGE__);
 
@@ -232,11 +232,7 @@ sub _encode_bifcode {
             '~' . ',';
         }
         elsif ( ( my $ref = ref $_ ) eq '' ) {
-            if ( utf8::is_utf8($_) ) {
-                utf8::encode( my $str = $_ );
-                'u' . length($str) . '.' . $str . ',';
-            }
-            elsif ( $_ =~ $number_qr ) {
+            if ( $_ =~ $number_qr ) {
                 if ( defined $3 or defined $5 ) {
 
                     # normalize to BIFCODE_REAL standards
@@ -249,11 +245,15 @@ sub _encode_bifcode {
                     'i' . $_ . ',';
                 }
             }
-            elsif ( $_ =~ m/[^\x{20}-\x{7E}]/ ) {
-                'b' . length($_) . '.' . $_ . ',';
+            elsif ( utf8::is_utf8($_) ) {
+                utf8::encode( my $str = $_ );
+                'u' . length($str) . '.' . $str . ',';
+            }
+            elsif ( $_ =~ m/^[\x{20}-\x{7E}]*$/ ) {
+                'u' . length($_) . '.' . $_ . ',';
             }
             else {
-                'u' . length($_) . '.' . $_ . ',';
+                'b' . length($_) . '.' . $_ . ',';
             }
         }
         elsif ( $ref eq 'ARRAY' ) {
@@ -269,15 +269,15 @@ sub _encode_bifcode {
                     map {
                         $k = shift @k;
 
-                        if ( utf8::is_utf8($k) ) {
+                        if ( $k =~ m/^[\x{20}-\x{7E}]*$/ ) {
+                            ( 'u' . length($k) . '.' . $k . ':', $_ );
+                        }
+                        elsif ( utf8::is_utf8($k) ) {
                             utf8::encode($k);
                             ( 'u' . length($k) . '.' . $k . ':', $_ );
                         }
-                        elsif ( $k =~ m/[^\x{20}-\x{7E}]/ ) {
-                            ( 'b' . length($k) . '.' . $k . ':', $_ );
-                        }
                         else {
-                            ( 'u' . length($k) . '.' . $k . ':', $_ );
+                            ( 'b' . length($k) . '.' . $k . ':', $_ );
                         }
                     } _encode_bifcode( @$_{@k} );
                   }
@@ -311,10 +311,6 @@ sub _encode_bifcode {
             utf8::encode($str);
             'u' . length($str) . '.' . $str . ',';
         }
-        elsif ( $ref eq 'Bifcode::BIFCODE' ) {
-            my $str = $$_ // _croak 'EncodeBifcodeUndef';
-            'B' . length($str) . '.' . $str . ',';
-        }
         else {
             _croak 'EncodeUnhandled', 'unhandled data type: ' . $ref;
         }
@@ -322,8 +318,16 @@ sub _encode_bifcode {
 }
 
 sub encode_bifcode {
-    _croak 'EncodeUsage' if @_ != 1;
-    bless \(&_encode_bifcode)[0], __PACKAGE__ . '::BIFCODE';
+    if ( ( @_ == 2 ) && pop ) {
+        my $b = (&_encode_bifcode)[0];
+        'B' . length($b) . '.' . $b . ',';
+    }
+    elsif ( @_ == 1 ) {
+        (&_encode_bifcode)[0];
+    }
+    else {
+        _croak 'EncodeUsage';
+    }
 }
 
 sub force_bifcode {
@@ -412,19 +416,11 @@ sub anyevent_read_type {
 }
 
 sub anyevent_write_type {
-    encode_bifcode( encode_bifcode( $_[1] ) ) . "\n";
+    encode_bifcode( $_[1], 1 ) . "\n";
 }
 
 1;
 
-package Bifcode::BIFCODE;
-use overload
-  bool     => sub { 1 },
-  '""'     => sub { ${ $_[0] } },
-  fallback => 1;
-
-1;
-
 __END__
 
 =pod
@@ -437,7 +433,7 @@ Bifcode - encode and decode BIFCODE serialization format
 
 =head1 VERSION
 
-2.000_6 (2019-11-12)
+2.000_7 (2019-11-13)
 
 =head1 SYNOPSIS
 
@@ -607,12 +603,13 @@ over a network.
 
 =head1 INTERFACE
 
-=head2 C<encode_bifcode( $datastructure )>
+=head2 C<encode_bifcode( $datastructure [, $enclose ] )>
 
-Takes a single argument which may be a scalar, or may be a reference to
-either a scalar, an array, a hash or a Bifcode::BIFCODE object. Arrays
-and hashes may in turn contain values of these same types. Returns a
-byte string blessed as C<Bifcode::BIFCODE>.
+The first argument (required) may be a scalar, or may be a reference to
+either a scalar, an array, or a hash. Arrays and hashes may in turn
+contain values of these same types. Returns the appropriate BIFCODE_*
+byte string. If $enclose is true then the result is further encoded
+as BIFCODE_BIFCODE.
 
 The mapping from Perl to I<BIFCODE> is as follows:
 
@@ -660,8 +657,6 @@ help with creating such references.
 
 =item * HASH references become BIFCODE_DICT.
 
-=item * Bifcode::BIFCODE references become BIFCODE_BIFCODE.
-
 =back
 
 This subroutine croaks on unhandled data types.
@@ -685,7 +680,7 @@ to a particular type (using blessed references) will decode as plain
 scalars.
 
 =item * BIFCODE_BIFCODE types are fully inflated into 
-Perl structures, and not the intermediate I<BIFCODE> string.
+Perl structures, and not the intermediate I<BIFCODE> byte string.
 
 =back
 
@@ -868,6 +863,9 @@ serialise a scalar. This cannot be fixed.
 This distribution includes the L<diff-bifcode> command-line utility for
 comparing I<BIFCODE> in files.
 
+L<Bifcode::V1> implements the original (experimental) I<BIFCODE>
+version 1.
+
 =head1 AUTHOR
 
 Mark Lawrence <nomad@null.net>, heavily based on Bencode by Aristotle
